# 2023-02-06 - Weighted Pool Factory V3

> ⚠️ **DEPRECATED: do not use** ⚠️
> This deployment has been deprecated in favor of a new version that uses create2 for pool deployments: [weighted-pool-v4](../../20230320-weighted-pool-v4/).

Deployment of the `WeightedPoolFactory`, which allows creating Weighted Pools.
Supersedes `20220908-weighted-pool-v2`, fixing the reentrancy issue described in this [forum post](https://forum.balancer.fi/t/reentrancy-vulnerability-scope-expanded/4345).

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [BSC mainnet addresses](./output/bsc.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Avalanche mainnet addresses](./output/avalanche.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`WeightedPool` artifact](./artifact/WeightedPool.json)
- [`WeightedPoolFactory` artifact](./artifact/WeightedPoolFactory.json)
